smartcard.wx.APDUHexValidator.APDUHexValidator

# ``smartcard`.`wx`.`APDUHexValidator`.`APDUHexValidator``

class documentation

`class APDUHexValidator(wx.PyValidator):`

View In Hierarchy

A wxValidator that matches APDU in hexadecimal such as: A4 A0 00 00 02 A4A0000002

Method | `__init__` | Undocumented
Method | `Clone` | Undocumented
Method | `OnChar` | Undocumented
Method | `Validate` | Undocumented

def __init__(self):

Undocumented

def Clone(self):

Undocumented

def OnChar(self, event):

Undocumented

def Validate(self, win):

Undocumented